package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaTque;

public interface IBisTtsaTqueService {
    BisTtsaTque selectBisTtsaTqueByGuid(String guid);
    List<BisTtsaTque> selectBisTtsaTqueList(BisTtsaTque bisTtsaTque);
    int insertBisTtsaTque(BisTtsaTque bisTtsaTque);
    int updateBisTtsaTque(BisTtsaTque bisTtsaTque);
    int deleteBisTtsaTqueByGuid(String guid);
    int deleteBisTtsaTqueByGuids(String[] guids);
}
